# README Laudatio Docker #

This is the Docker container setup for the Laudatio web application

## INSTALLATION ##

``` 
>> git clone git@scm.cms.hu-berlin.de:hu-berlin-laudatio-repository/laudatio-docker.git
>> git submodule init && git submodule update
>> cd laudatio-repository
```

## CONFIGURATION ##

* nano composer.json
* change

```
"autoload" : {
		"psr-4" : {
			"App\\" : "app/"
		},
	 "classmap": [
	            "database/seeds",
	            "database/factories",
	                        "vendor/olendorf/ezid-php"
	        ]
}
```

* into


```
"autoload" : {
		"psr-4" : {
			"App\\" : "app/"
		},
	 "classmap": []
}
```
      

```
>> cd ..
>> mkdir docker-config/app/ssh/www-data-ssh
```

* create ssh-keys for your corpus gitlab repository [Generating a new SSH key pair](https://docs.gitlab.com/ee/ssh/README.html#generating-a-new-ssh-key-pair "How to generate ssh keys")
* create a RSA key with the name "laudaadm_rsa"
* create a RSA key with the name "id_rsa"
* add the ssh keys to docker-config/app/ssh/www-data-ssh (id_rsa && id_rsa.pub and laudaadm_rsa and laudaadm_rsa.pub)
* copy docker-config/app/ssh/www-data-ssh/config_template to docker-config/app/ssh/www-data-ssh/config
* edit docker-config/app/ssh/www-data-ssh/config and replace the domain of your gitlab for "{your-gitlab-host}"
* add the [ssh keys to your gitlab account](https://docs.gitlab.com/ee/ssh/README.html#adding-an-ssh-key-to-your-gitlab-account)
* copy `.env.template` to `.env`
* copy `docker-config/app/.env.prod` to `docker-config/app/.env`
* edit docker-config/app/.env and enter passwords for DB, DATACITE AND LDAP
* add a new user group "docker": 
  * Linux: `sudo groupadd docker`
  * Mac OS: `sudo dscl . -create /groups/docker`
* add a new user to the docker group: 
  * Linux: `sudo gpasswd -a $USER docker`
  * Mac OS: `sudo dseditgroup -o edit -a $USER -t user docker`
* `newgrp docker` (probably not needed on Mac OS)

```
>> cd docker-data-volumes/elasticsearch
>> mkdir -p 1/backups/elasticsearch
>> mkdir -p 1/backups/nodes
>> mkdir -p 2/backups/elasticsearch
>> mkdir -p 2/backups/nodes
>> mkdir -p 3/backups/elasticsearch
>> mkdir -p 4/backups/nodes
>> chown -R 1000:1000 1
>> chown -R 1000:1000 2
>> chown -R 1000:1000 3
```


## Build ##
Building for the first time:

1. Create certificates for TLS support:

```

 `docker-compose -f docker-helpers.yml run --rm create_certs`

```
Certificates will be stored in a named volume (`certs`). Later on, your containers for Elasticsearch and Kibana will use that named volume to access the necessary certificates for supporting TLS communication.

2. bring the elasticsearch containers up
```

 `docker-compose up -d es01 es02 es03`
 
```
NOTE: If the elasticsearch containers keep exiting with code 137, you may need to increase the memory limit for Docker to at least 6 GB. Also, look into the vm.max_map_count setting: https://www.elastic.co/guide/en/elasticsearch/reference/current/vm-max-map-count.html


3. Visit https://localhost:9200/ to make sure that Elasticsearch is running. It may take a few minutes to get started.

4. generate elasticsearch passwords

```

 `docker exec es01 /bin/bash -c "bin/elasticsearch-setup-passwords auto --batch --url https://es01:9200" > es_pw.txt`

```
NOTE: If the command fails to authenticate for the built-in user 'elastic', stop the containers, delete the data volume folders (1, 2, 3) in `docker-data-volumes/elasticsearch` then restart the containers and try to execute the command again.

5. Update the password for Kibana: 

```

`docker-compose -f docker-helpers.yml run --rm update_password`

```

6. Start all other services:

```

 `docker-compose up -d`

```

Subsequent runs:

``` 
>> docker-compose up -d
>> docker-compose down

```

## Using the app
Visit http://localhost:8990 to access the Laudatio web frontend.

## Create Elasticsearch Indexes ## 
* create elasticsearch index templates

```
>> docker exec -it es01 bash

>> curl -uelastic:{password} -XPUT  https://es01:9200/_index_template/corpora_template -H 'Content-Type: application/json' -d  @corpora_template.json --insecure
	should return: {"acknowledged":true}
	
>> curl -uelastic:{password} -XPUT  https://es01:9200/_index_template/documents_template -H 'Content-Type: application/json' -d  @documents_template.json --insecure
	should return: {"acknowledged":true}
	
>> curl -uelastic:{password} -XPUT  https://es01:9200/_index_template/annotations_template -H 'Content-Type: application/json' -d  @annotations_template.json --insecure
	should return: {"acknowledged":true}
	
>> curl -uelastic:{password} -XPUT  https://es01:9200/_index_template/guidelines_template -H 'Content-Type: application/json' -d  @guidelines_template.json --insecure
	should return: {"acknowledged":true}
```
	
* create the elasticsearch indexes

```
>> curl -u elastic:{password} -XPUT  https://es01:9200/corpora?pretty --insecure
      should return:
        {
          "acknowledged" : true,
          "shards_acknowledged" : true,
          "index" : "corpora"
        }
        
>> curl -u elastic:{password} -XPUT  https://es01:9200/documents?pretty --insecure
        should return:
        {
	          "acknowledged" : true,
	          "shards_acknowledged" : true,
	          "index" : "documents"
          }
          
>> curl -u elastic:{password} -XPUT  https://es01:9200/annotations?pretty --insecure
        should return:
        	{
	          "acknowledged" : true, 
	          "shards_acknowledged" : true,
	          "index" : "annotations"
        	}
        	
>> curl -u elastic:{password} -XPUT  https://es01:9200/guidelines?pretty --insecure
        should return:
            {
              "acknowledged" : true,
              "shards_acknowledged" : true,
              "index" : "guidelines"

            }

```

## Adding XML data to the ElasticSearch index (and searching for stuff)
Run `docker-compose -f docker-helpers.yml run --rm add_xml_data_to_elasticsearch`
