FROM php:7.4-fpm

# add new user to the new group
RUN adduser www-data www-data

RUN apt-get update && \
    apt-get install -y libldap2-dev && \
    apt-get install -y python3-pip python-dev python3-venv && \
    apt-get install -y git && \
    apt-get install -y zip && \
    apt-get install -y libmcrypt-dev libmagickwand-dev --no-install-recommends && \
    apt-get install -y libpq-dev nano lsof && \
	apt-get install -y postgresql-client

RUN pecl install mcrypt-1.0.3

# Setup Corpus Git environment and logging
RUN mkdir -p laudatiofiles/gitfiles laudatiofiles/laudatiologs
RUN chown -R www-data:www-data laudatiofiles/gitfiles laudatiofiles/laudatiologs
RUN touch laudatiofiles/laudatiologs/pipeline.log

RUN rm -rf /var/lib/apt/lists/*

RUN docker-php-ext-configure ldap --with-libdir=lib/x86_64-linux-gnu/ && \
    docker-php-ext-install ldap && \
    docker-php-ext-enable mcrypt
# Install Postgres PDO
RUN docker-php-ext-configure pgsql -with-pgsql=/usr/local/pgsql && \
    docker-php-ext-install pdo pdo_pgsql pgsql

COPY ./laudatio-repository/composer.lock ./laudatio-repository/composer.json /var/www/
COPY ./docker-config/app/pip.txt /root/.
COPY ./docker-config/app/.bashrc /root/.

WORKDIR /root

ENV VIRTUAL_ENV=/opt/venv
RUN python3 -m venv $VIRTUAL_ENV
ENV PATH="$VIRTUAL_ENV/bin:$PATH"

RUN pip3 install --upgrade pip && \
    pip3 install --no-cache-dir -r /root/pip.txt

COPY ./docker-config/app/datacite/schema42.py /opt/venv/lib/python3.7/site-packages/datacite/.
COPY ./docker-config/app/datacite/datacite-v4.2.json /opt/venv/lib/python3.7/site-packages/datacite/schemas/.

RUN mkdir /home/www-data; \
    usermod -d /home/www-data www-data; \
    mkdir /home/www-data/.ssh;

COPY ./docker-config/app/ssh/www-data-ssh/* /home/www-data/.ssh/
COPY ./docker-config/app/.bashrc /home/www-data/.
COPY ./docker-config/app/.gitconfig /home/www-data/.

RUN chown -R www-data:www-data /home/www-data/.ssh
RUN chown -R www-data:www-data /home/www-data/.bashrc
RUN chown www-data:www-data /home/www-data/.gitconfig
RUN chmod 700 /home/www-data/.ssh
RUN chmod 644 /home/www-data/.ssh/config /home/www-data/.ssh/id_rsa.pub /home/www-data/.ssh/laudaadm_rsa.pub
RUN chmod 600 /home/www-data/.ssh/id_rsa /home/www-data/.ssh/laudaadm_rsa

WORKDIR /var/www/laudatiodata/gitfiles/projects

RUN git config --global user.email "laudaadm@hu-berlin.de"; \
    git config --global user.name "Laudatio Repository"

COPY ./docker-config/app/.gitconfig /var/www/.gitconfig

WORKDIR /var/www

COPY ./docker-config/app/php.ini /usr/local/etc/php/php.ini

#look for updated SHA: https://composer.github.io/pubkeys.html
# or https://getcomposer.org/doc/faqs/how-to-install-composer-programmatically.md
RUN php -r "copy('https://getcomposer.org/installer', 'composer-setup.php');" \
    && php -r "if (hash_file('SHA384', 'composer-setup.php') === '756890a4488ce9024fc62c56153228907f1545c228516cbf63f885e036d37e9a59d27d63f46af1d4d07ee0f76181c7d3') { echo 'Installer verified'; } else { echo 'Installer corrupt'; unlink('composer-setup.php'); } echo PHP_EOL;" \
    && php composer-setup.php \
    && php -r "unlink('composer-setup.php');" \
    && php composer.phar install --no-dev --no-scripts

# uncomment this for debugging
#RUN pecl install xdebug
#RUN docker-php-ext-enable xdebug

COPY ./laudatio-repository/ /var/www/

RUN if [ -f "/var/www/storage" ]; then \
        rm -rf /var/www/storage; \
    else \
        mkdir /var/www/storage; \
		mkdir /var/www/storage/logs; \
        mkdir /var/www/storage/app; \
        mkdir /var/www/storage/framework; \
        mkdir /var/www/storage/framework/cache; \
        mkdir /var/www/storage/framework/sessions; \
        mkdir /var/www/storage/framework/views; \
        mkdir /var/www/storage/responses; \
    fi;

RUN chown -R www-data:www-data /var/www/storage /var/www/bootstrap/cache /var/www/public

COPY ./docker-config/app/.env /var/www/.env
RUN chmod 777 /var/www/.env
COPY ./docker-config/app/entrypoint.sh /entrypoint.sh
ENTRYPOINT ["/entrypoint.sh"]
